@@ -15,6 +15,8 @@ import com.google.protobuf.Parser;
 import com.google.protobuf.conformance.Conformance;
 import com.google.protobuf_test_messages.edition2023.TestAllTypesEdition2023;
 import com.google.protobuf_test_messages.edition2023.TestMessagesEdition2023;
+import com.google.protobuf_test_messages.edition_unstable.TestAllTypesEditionUnstable;
+import com.google.protobuf_test_messages.edition_unstable.TestMessagesEditionUnstableProto;
 import com.google.protobuf_test_messages.editions.proto2.TestMessagesProto2Editions;
 import com.google.protobuf_test_messages.editions.proto3.TestMessagesProto3Editions;
 import com.google.protobuf_test_messages.proto2.TestMessagesProto2;
@@ -216,6 +218,8 @@ class ConformanceJavaLite {
         return TestAllTypesProto2.class;
       case "protobuf_test_messages.editions.TestAllTypesEdition2023":
         return TestAllTypesEdition2023.class;
+      case "protobuf_test_messages.edition_unstable.TestAllTypesEditionUnstable":
+        return TestAllTypesEditionUnstable.class;
       case "protobuf_test_messages.editions.proto3.TestAllTypesProto3":
         return TestMessagesProto3Editions.TestAllTypesProto3.class;
       case "protobuf_test_messages.editions.proto2.TestAllTypesProto2":
@@ -234,6 +238,8 @@ class ConformanceJavaLite {
         return TestMessagesProto2.class;
       case "protobuf_test_messages.editions.TestAllTypesEdition2023":
         return TestMessagesEdition2023.class;
+      case "protobuf_test_messages.edition_unstable.TestAllTypesEditionUnstable":
+        return TestMessagesEditionUnstableProto.class;
       case "protobuf_test_messages.editions.proto3.TestAllTypesProto3":
         return TestMessagesProto3Editions.class;
       case "protobuf_test_messages.editions.proto2.TestAllTypesProto2":
