@@ -38,7 +38,8 @@ abstract class AbstractProtobufList<E> extends AbstractList<E> implements Protob
   }
 
   @Override
-  public boolean equals(Object o) {
+  public boolean equals(
+          Object o) {
     if (o == this) {
       return true;
     }
